%define qemu_name	qemu-kvm
%define qemu_version	0.15.0
%define qemu_rel	1
#define qemu_snapshot	0
%define qemu_release	%mkrel %{?qemu_snapshot:0.%{qemu_snapshot}.}%{qemu_rel}

%define __find_requires %{_builddir}/%{qemu_name}-%{qemu_version}%{?qemu_snapshot:-%{qemu_snapshot}}/find_requires.sh

Summary:	QEMU CPU Emulator
Name:		qemu
Version:	%{qemu_version}
Release:	%{qemu_release}
Source0:	http://downloads.sourceforge.net/project/kvm/%{qemu_name}/%{version}/%{qemu_name}-%{version}%{?qemu_snapshot:-%{qemu_snapshot}}.tar.gz
Source1:	kvm.modules
Patch0:		qemu-kvm-compile-fix.patch
Patch4:		hw-pl110-Model-the-PL111-CLCD-controller.patch
Patch5:		versatilepb-Implement-SYS_CLCD-mux-control-register-.patch

# KSM control scripts
Source4: ksm.init
Source5: ksm.sysconfig
Source6: ksmtuned.init
Source7: ksmtuned
Source8: ksmtuned.conf

License:	GPL
URL:		http://wiki.qemu.org/Main_Page
Group:		Emulators
Provides:	kvm
Obsoletes:	kvm < 86
Requires:	qemu-img = %{version}-%{release}
# for %%{_sysconfdir}/sasl2
Requires:	cyrus-sasl
BuildRequires:	libSDL-devel
BuildRequires:	texi2html
# XXXX: -luuid
BuildRequires:	e2fsprogs-devel
BuildRequires:	kernel-headers	
BuildRequires:	pulseaudio-devel
BuildRequires:	zlib-devel
BuildRequires:	brlapi-devel
BuildRequires:	gnutls-devel
BuildRequires:	libsasl2-devel
BuildRequires:	%{_lib}pci-devel
BuildRequires:	texinfo
# not in main
#BuildRequires:	vde-devel
BuildRequires:	dev86
BuildRequires:	iasl
# glibc-devel with fixed preadv/pwritev prototypes
BuildRequires:	glibc-devel >= 6:2.10.1-7mnb2
ExclusiveArch:	%{ix86} ppc x86_64 amd64 %{sunsparc}
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
QEMU is a FAST! processor emulator. By using dynamic translation it
achieves a reasonnable speed while being easy to port on new host
CPUs. QEMU has two operating modes:

* User mode emulation. In this mode, QEMU can launch Linux processes
  compiled for one CPU on another CPU. Linux system calls are
  converted because of endianness and 32/64 bit mismatches. Wine
  (Windows emulation) and DOSEMU (DOS emulation) are the main targets
  for QEMU.

* Full system emulation. In this mode, QEMU emulates a full system,
  including a processor and various peripherials. Currently, it is
  only used to launch an x86 Linux kernel on an x86 Linux system. It
  enables easier testing and debugging of system code. It can also be
  used to provide virtual hosting of several virtual PC on a single
  server.

%package img
Summary:	QEMU disk image utility
Group:		Emulators
Version:	%{qemu_version}
Release:	%{qemu_release}
Conflicts:	qemu < 0.9.0-%{mkrel 3}

%description img
This package contains the QEMU disk image utility that is used to
create, commit, convert and get information from a disk image.

%prep
%setup -q -n %{qemu_name}-%{qemu_version}%{?qemu_snapshot:-%{qemu_snapshot}}
%patch0 -p0
%patch4 -p1
%patch5 -p1

# nuke explicit dependencies on GLIBC_PRIVATE
# (Anssi 03/2008) FIXME: use _requires_exceptions
cat >find_requires.sh << EOF
#!/bin/sh
%{_prefix}/lib/rpm/find-requires %{buildroot} %{_target_cpu} | grep -v GLIBC_PRIVATE
EOF
chmod +x find_requires.sh

%build
# don't use -mtune=generic if it is not supported
if ! echo | %{__cc} -mtune=generic -xc -c - -o /dev/null 2> /dev/null; then
  CFLAGS=`echo "$RPM_OPT_FLAGS" | sed -e "s/-mtune=generic/-mtune=pentiumpro/g"`
fi
 
extraldflags="-Wl,--build-id";
buildldflags="VL_LDFLAGS=-Wl,--build-id"

%ifarch %{ix86} x86_64
# sdl outputs to alsa or pulseaudio depending on system config, but it's broken (RH bug #495964)
# alsa works, but causes huge CPU load due to bugs
# oss works, but is very problematic because it grabs exclusive control of the device causing other apps to go haywire
./configure \
	--target-list=x86_64-softmmu \
	--prefix=%{_prefix} \
	--sysconfdir=%{_sysconfdir} \
	--audio-drv-list=pa,sdl,alsa,oss \
	--extra-ldflags=$extraldflags \
	--extra-cflags="$CFLAGS"

%make V=1 $buildldflags
cp -a x86_64-softmmu/qemu-system-x86_64 qemu-kvm
make clean

#pushd kvm
#./configure \
#	--prefix=%{_prefix} \
#	--kerneldir="`pwd`/../kernel/" \
#	--with-kvm-trace
##make kvmtrace
#make
#popd
%endif

./configure \
	--target-list="i386-softmmu x86_64-softmmu arm-softmmu cris-softmmu m68k-softmmu \
		mips-softmmu mipsel-softmmu mips64-softmmu mips64el-softmmu ppc-softmmu \
		ppcemb-softmmu ppc64-softmmu sh4-softmmu sh4eb-softmmu sparc-softmmu \
		i386-linux-user x86_64-linux-user alpha-linux-user arm-linux-user \
		armeb-linux-user cris-linux-user m68k-linux-user mips-linux-user \
		mipsel-linux-user ppc-linux-user ppc64-linux-user ppc64abi32-linux-user \
		sh4-linux-user sh4eb-linux-user sparc-linux-user sparc64-linux-user \
		sparc32plus-linux-user" \
	--prefix=%{_prefix} \
	--sysconfdir=%{_sysconfdir} \
	--interp-prefix=%{_prefix}/qemu-%%M \
	--audio-drv-list=pa,sdl,alsa,oss \
	--disable-kvm \
	--extra-ldflags=$extraldflags \
	--extra-cflags="$CFLAGS"

%make V=1 $buildldflags

%install
rm -rf $RPM_BUILD_ROOT

install -D -p -m 0755 %{SOURCE4} $RPM_BUILD_ROOT%{_initrddir}/ksm
install -D -p -m 0644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/ksm

install -D -p -m 0755 %{SOURCE6} $RPM_BUILD_ROOT%{_initrddir}/ksmtuned
install -D -p -m 0755 %{SOURCE7} $RPM_BUILD_ROOT%{_sbindir}/ksmtuned
install -D -p -m 0644 %{SOURCE8} $RPM_BUILD_ROOT%{_sysconfdir}/ksmtuned.conf

%ifarch %{ix86} x86_64
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules
mkdir -p $RPM_BUILD_ROOT%{_bindir}/
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}

install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules/kvm.modules
install -m 0755 kvm/kvm_stat $RPM_BUILD_ROOT%{_bindir}/
install -m 0755 qemu-kvm $RPM_BUILD_ROOT%{_bindir}/
%endif

%makeinstall_std BUILD_DOCS="yes"

install -D -p -m 0644 qemu.sasl $RPM_BUILD_ROOT%{_sysconfdir}/sasl2/qemu.conf

#QPM
install -m 0755 QMP/qmp-shell $RPM_BUILD_ROOT/%{_bindir}/qmp-shell
install -d $RPM_BUILD_ROOT/%{py_platsitedir}
install -m 0755 QMP/qmp.py $RPM_BUILD_ROOT/%{py_platsitedir}/qmp.py

# remove unpackaged files
rm -rf $RPM_BUILD_ROOT%{_docdir}/qemu

%clean
rm -rf $RPM_BUILD_ROOT

%post 
%ifarch %{ix86} x86_64
# load kvm modules now, so we can make sure no reboot is needed.
# If there's already a kvm module installed, we don't mess with it
sh /%{_sysconfdir}/sysconfig/modules/kvm.modules
%endif
%_post_service ksmtuned
%_post_service ksm

%preun
%_preun_service ksm
%_preun_service ksmtuned

%triggerpostun -- qemu < 0.10.4-6
rm -f /etc/rc.d/*/{K,S}??qemu

%files
%defattr(-,root,root)
%doc README qemu-doc.html qemu-tech.html
%config(noreplace)%{_sysconfdir}/sasl2/qemu.conf
%{_initrddir}/ksm
%config(noreplace) %{_sysconfdir}/sysconfig/ksm
%{_initrddir}/ksmtuned
%{_sbindir}/ksmtuned
%config(noreplace) %{_sysconfdir}/ksmtuned.conf
%{_sysconfdir}/sysconfig/modules/kvm.modules
%{_sysconfdir}/qemu/target-x86_64.conf
%{_bindir}/kvm_stat
%{_bindir}/qemu-io
%{_bindir}/qemu-kvm
%{_bindir}/qemu
%{_bindir}/qemu-alpha
%{_bindir}/qemu-arm*
%{_bindir}/qemu-cris
%{_bindir}/qemu-ga
%{_bindir}/qemu-i386
%{_bindir}/qemu-m68k
%{_bindir}/qemu-mips*
%{_bindir}/qemu-nbd
%{_bindir}/qemu-ppc*
%{_bindir}/qemu-sh4*
%{_bindir}/qemu-sparc*
%{_bindir}/qemu-x86_64
%{_bindir}/qemu-system-arm
%{_bindir}/qemu-system-cris
%{_bindir}/qemu-system-m68k
%{_bindir}/qemu-system-sh4*
%{_bindir}/qemu-system-ppc*
%{_bindir}/qemu-system-mips*
%{_bindir}/qemu-system-sparc
%{_bindir}/qemu-system-x86_64
%{_bindir}/qmp-shell
%{_mandir}/man1/qemu.1*
%{_mandir}/man8/qemu-nbd.8*
%dir %{_datadir}/qemu
%{_datadir}/qemu/*.bin
%{_datadir}/qemu/*.rom
%{_datadir}/qemu/keymaps
%{_datadir}/qemu/openbios-sparc32
%{_datadir}/qemu/openbios-sparc64
%{_datadir}/qemu/openbios-ppc
%{_datadir}/qemu/bamboo.dtb
%{_datadir}/qemu/mpc8544ds.dtb
%{_datadir}/qemu/petalogix-ml605.dtb
%{_datadir}/qemu/petalogix-s3adsp1800.dtb
%{py_platsitedir}/qmp.py
%files img
%defattr(-,root,root)
%{_bindir}/qemu-img
%{_mandir}/man1/qemu-img.1*


%changelog
* Mon Aug 22 2011 Lonyai Gergely <aleph@mandriva.org> 0.15.0-1mdv2011.0
+ Revision: 696214
- 0.15.0
  patch set import from cooker

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - no need to use texi2html from tetex

* Fri Apr 01 2011 Buchan Milne <bgmilne@mandriva.org> 0.14.0-1
+ Revision: 649573
- Use %%_initrddir instead of %%_initddir
- Fix build of non-x86 targets which dont have PCI support

  + Lonyai Gergely <aleph@mandriva.org>
    - 0.14.0

* Sat Dec 04 2010 Lonyai Gergely <aleph@mandriva.org> 0.13.0-1mdv2011.0
+ Revision: 608879
- Fix the sysconfdir param
- Add some files to %%files
- try the official doc/man install
- Install manualy the man pages.
- Install manualy qemu manpage
- Does not run compile in the user dir
- Disable the kvm_trace tool.
- 0.13.0

  + Funda Wang <fwang@mandriva.org>
    - br makeinfo

  + Thierry Vignaud <tv@mandriva.org>
    - fix outdated URL

* Wed Aug 25 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.12.5-1mdv2011.0
+ Revision: 573124
- new version

* Fri Jul 16 2010 Funda Wang <fwang@mandriva.org> 0.12.4-1mdv2011.0
+ Revision: 553901
- New version 0.12.4

* Mon Mar 01 2010 Frederic Crozat <fcrozat@mandriva.com> 0.12.3-2mdv2010.1
+ Revision: 512912
- Ensure kvm modules autoload can be blacklisted (Fedora)

* Sun Feb 28 2010 Frederik Himpe <fhimpe@mandriva.org> 0.12.3-1mdv2010.1
+ Revision: 512672
- Update to new version 0.12.3

* Thu Jan 21 2010 Frederik Himpe <fhimpe@mandriva.org> 0.12.2-1mdv2010.1
+ Revision: 494681
- Update to new version 0.12.2

* Fri Jan 01 2010 Frederik Himpe <fhimpe@mandriva.org> 0.12.1.2-1mdv2010.1
+ Revision: 484859
- Update to new version 0.12.1.2
- Remove old patches

* Tue Dec 15 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.1-1mdv2010.1
+ Revision: 479125
- Update to new version 0.11.1
- Enable KSM support now that we have Linux 2.6.32 with KSM support
  (from Fedora)

* Mon Nov 23 2009 Pascal Terjan <pterjan@mandriva.org> 0.11.0-5mdv2010.1
+ Revision: 469231
- Drop kqemu support, it is now broken so no reason to limit supported memory in kvm

* Thu Nov 12 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.11.0-4mdv2010.1
+ Revision: 465471
- Rebuild with latest glibc-devel (fixed preadv/pwritev prototypes).

* Wed Oct 14 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-3mdv2010.0
+ Revision: 457437
- Add Fedora patch to Fix fs errors with virtio and qcow2 backing file
  (RH bug #524734)

* Sun Oct 04 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-2mdv2010.0
+ Revision: 453566
- Sync patches with Fedora

* Thu Oct 01 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-1mdv2010.0
+ Revision: 452301
- Update to new version 0.11.0 final

* Mon Sep 14 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-0.rc2.2mdv2010.0
+ Revision: 441019
- Update to new version 0.11.0-rc2
- Remove patched included upstream

* Sat Aug 08 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-0.rc2.1mdv2010.0
+ Revision: 411756
- Remove warning about permissions on KVM device, now udev only
  gives access to console users

* Sat Aug 08 2009 Frederik Himpe <fhimpe@mandriva.org> 0.10.6-1mdv2010.0
+ Revision: 411755
- Don't package udev rules, /lib/udev/rules.d/70-acl.rules from udev
  package now takes care of this
- Update to new version 0.10.6

* Wed Jul 01 2009 Pascal Terjan <pterjan@mandriva.org> 0.10.5-1mdv2010.0
+ Revision: 391268
- Enable kqemu support
- Update to 0.10.5

* Sun May 24 2009 Frederik Himpe <fhimpe@mandriva.org> 0.10.4-7mdv2010.0
+ Revision: 379273
- Correct sasl BuildRequires
- Add warning about security issue with /dev/kvm being accessible by
  non-root users
- Add KVM udev rules to let normal users use KVM
- Mark configuration files as %%config(noreplace)
- Enable sasl authentication
- Sync patches with Fedora 11

* Sat May 23 2009 Frederik Himpe <fhimpe@mandriva.org> 0.10.4-6mdv2010.0
+ Revision: 379080
- Disable vde, it's not in main
- Add some BuildRequires (build with vde, brlapi and VNC/TLS support)
- Remove old qemu init script on upgrade
- Use qemu-kvm 0.10.4 sources
- Obsolete kvm
- Remove kqemu: it is unmaintained and unreliable
- Use /etc/sysconfig/modules/kvm.modules to load KVM kernel modules
- Merge %%build section from Fedora's qemu package: build qemu-kvm twice:
  once with KVM support for x86* and once without kvm support
- Add PPC patch from Fedora to fix build of PPC emulator
- Add patch fixing kerneldir includes from upstream git to fix build of KVM

* Tue May 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.10.4-5mdv2010.0
+ Revision: 375044
- Update to new version 0.10.4
- Update to new version 0.10.3
- Prefer sdl over alsa because sound with alsa is choppy

* Sun Mar 22 2009 Frederik Himpe <fhimpe@mandriva.org> 0.10.1-3mdv2009.1
+ Revision: 360260
- Update to new version 0.10.1

* Fri Mar 06 2009 Pascal Terjan <pterjan@mandriva.org> 0.10.0-2mdv2009.1
+ Revision: 349652
- Update to 0.10.0
- Enable ppc again

* Wed Feb 04 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.1-0.r5137.2mdv2009.1
+ Revision: 337395
- rediff vga patch
- keep bash completion in its own package

* Mon Sep 08 2008 Pascal Terjan <pterjan@mandriva.org> 0.9.1-0.r5137.1mdv2009.0
+ Revision: 282565
- Update to svn snapshot
- Drop KVM support (to be packaged separatly)
- Disable ppc for now

* Tue Apr 01 2008 Pascal Terjan <pterjan@mandriva.org> 0.9.0-18mdv2008.1
+ Revision: 191380
- try SDL, alsa, oss instead of oss, alsa, SDL

  + Anssi Hannula <anssi@mandriva.org>
    - add a comment regarding _requires_exceptions

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Dec 08 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.9.0-17mdv2008.1
+ Revision: 116405
- backport OHCI & UHCI iso transfer support from git (should make webcams usable :)
- fix typo in bash completion (modified S3)

* Mon Oct 01 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-16mdv2008.0
+ Revision: 94272
- Add a link /usr/bin/qemu-kvm for compatibility with some other distros

* Sat Sep 22 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-15mdv2008.0
+ Revision: 92233
- Have the completion to add the common prefix (really handy to change iso during install)

* Fri Sep 21 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-14mdv2008.0
+ Revision: 91894
- Enable alsa support (and don't disable gcc version check twice)

* Mon Sep 17 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-13mdv2008.0
+ Revision: 89251
- Add mipsel system emulation

* Thu Sep 06 2007 Olivier Blin <blino@mandriva.org> 0.9.0-12mdv2008.0
+ Revision: 80664
- fix "HSM violation" bug in ATAPI cdrom driver (from qemu CVS, Novell #291775, Ubuntu #120316)

* Mon Aug 20 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-11mdv2008.0
+ Revision: 67355
- Turn Requires dkms-kqemu into a Suggest

* Mon Aug 20 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-10mdv2008.0
+ Revision: 67187
- Drop cpu-vendor option from kvm patch for now, it breaks build on x86_64
- Update to kvm-35
- Add a patch from the ML to support USB devices with several interfaces

* Fri Aug 10 2007 Pascal Terjan <pterjan@mandriva.org> 0.9.0-9mdv2008.0
+ Revision: 61527
- Adapt the PXE patches and apply them

  + Erwan Velu <erwan@mandriva.org>
    - Adding patches to make pxe working

* Sat Jun 30 2007 Olivier Blin <blino@mandriva.org> 0.9.0-8mdv2008.0
+ Revision: 46094
- fix __find_requires macro override
- really package bash_completion file (and thus fix build)
- do not mark initscript as config file

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - bash completion

* Fri Apr 20 2007 Gwenole Beauchesne <gbeauchesne@mandriva.org> 0.9.0-7mdv2008.0
+ Revision: 16259
- rewrite patches for gcc4 support and use it everywhere

* Wed Apr 18 2007 Gwenole Beauchesne <gbeauchesne@mandriva.org> 0.9.0-6mdv2008.0
+ Revision: 14738
- fix pgtable calculation for 32-bit code under x86_64 (Bernhard Kauer)
- fix qcow2 image corruption, refcount table (Juergen Keil)
- fix build with gcc3.3 (Windows XP in i386-softmmu)


* Tue Mar 27 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.0-5mdv2007.1
+ Revision: 149237
- fix x86 fprem, aka fix konqueror in x86{,_64} guests (Julian Seward)
- propagate release to dkms config so that to handle upgrades gracefully
- don't try to load kvm module in xen0
- increase max -kernel size to 8 MB with -initrd (x86_64 guest, in particular)

* Thu Mar 15 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.0-4mdv2007.1
+ Revision: 144294
- kqemu 1.3.0pre11 (no change)
- fix linux-user emulation on x86_64
- disable "no-nptl" patch for MDV >= 2007.0
- add should-start: dkms to initscript (blino)
- add conflicts to ensure upgrades from MDV < 2007.1

* Wed Mar 14 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.0-3mdv2007.1
+ Revision: 143511
- split off qemu-img into another package
- make "qemu" the accelerator-capable binary on x86_64 too
- add KVM support (rev 4486)
- add live migration support (Anthony Liguori + KVM SVN)
- fix support for multi-threaded applications in linux-user

* Wed Feb 14 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.0-2mdv2007.1
+ Revision: 120890
- add support for vga= option with -kernel (Pascal Terjan)
- updates from CVS (2007/02/14):
  * fix SYSLINUX hang (reset rombios32 area)
  * fix floating point to integer conversion in sparc emulation
  * serial console improvements
  * increase USB table poll interval
  * more linux-user syscalls: prctl, syslog

* Tue Feb 06 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.0-1mdv2007.1
+ Revision: 116853
- 0.9.0
- integrate kqemu

* Sat Feb 03 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.8.3-0.20070203.1mdv2007.1
+ Revision: 116057
- 64-bit fixes (preserve host registers)
- x86_64 host improvements (+15%% on nbench.flp)
- remove qvm86 accelerator (obsolete and unmaintained)
- updates from CVS (2007/02/03):
  * fix x86_64 syscalls, cwde and cdq
  * add sem*() and msg*() to linux-user emulation
  * add PIIX4 SMBus host support, EEPROM device emulation

* Tue Jan 30 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.8.3-0.20070118.1mdv2007.1
+ Revision: 115559
- 0.8.3 snapshot (2007/01/18)

* Mon Jul 24 2006 trem <trem@mandriva.org> 0.8.2-1mdv2007.0
- 0.8.2

* Thu Jul 20 2006 trem <trem@mandriva.org> 0.8.1-2mdv2007.0
- add Patch20 which fix a compile error
- add arm-softmmu as target

* Thu May 04 2006 trem <trem@mandriva.org> 0.8.1-1mdk
- 0.8.1
- remove useless patch

* Mon Feb 13 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.8.0-4mdk
- fix gcc4 hacks for 0.8.0
- enforce 16-byte stack boundaries
- try to enforce only one exit point per synthetic opcode
- assorted fixes from cvs (2006/02/12):
  * fxsave/fxrstor fix
  * kqemu and SMP are currently not compatible
  * make target_mmap always return -1 on failure
  * correct DMA and transfer mode reporting (Jens Axboe)

* Sun Feb 05 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.8.0-3mdk
- add rtl8139 nic emulation (Igor Kovalenko)
- add support for nic card selection (-nic hw=ne2000|pcnet|rtl8139)
- fix but remove x86_64 softmmu asm opts as sizeof(CPUTLBEntry) is no
  longer of the form 2^n and thus requiring one more instruction that
  renders the optimization worthless

* Mon Jan 16 2006 trem <trem@mandriva.org> 0.8.0-2mdk
- Fix x86_64 compilation (disable patch x86_64-softmmu-asm)

* Tue Dec 20 2005 Pascal Terjan <pterjan@mandriva.org> 0.8.0-1mdk
- 0.8.0
- rediffed P8, P16
- merged P13 into P2
- dropped P12
- updated P11
- don't apply sheep-net patch for now, gb will do :)
- add patch by Paul Brook to speedup user-net (P19)

* Fri Oct 28 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.7.2-5mdk
- more gcc4 patches, disabled for now because of x86_64-softmmu

* Tue Oct 25 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.7.2-4mdk
- linux-user improvements:
  * add AT_PLATFORM & AT_HWCAP entries to auxiliary vector
  * forcibly disable use of NPTL for now since it's not emulated yet

* Tue Oct 11 2005 Pascal Terjan <pterjan@mandriva.org> 0.7.2-3mdk
- Enable building kqemu/qvm86 support (P12) :
  * don't require the sources of current kernel
  * as we don't know the kernel, enforce 2.6 build style

* Tue Oct 11 2005 Erwan Velu <erwan@seanodes.com> 0.7.2-2mdk
- Oops, 0.7.2-1mdk wasn't good :(
- importing newest kqemu.h
- qvm86 updates from CVS (2005/10/10)

* Mon Oct 10 2005 Erwan Velu <erwan@seanodes.com> 0.7.2-1mdk
- 0.7.2
- Rediffing to 0.7.2
- patch13 is merged upstream

* Thu Aug 11 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.7.1-3mdk
- IDE fix from CVS for FreeBSD/AMD64 support
- run-time detect qvm86/kqemu and enable specific features accordingly
- qvm86 updates from CVS (2005/08/01):
  * performance improvements
  * add support for pae enabled host kernels

* Mon Jul 25 2005 Pascal Terjan <pterjan@mandriva.org> 0.7.1-2mdk
- use new kqemu.h from kqemu 
- enable kqemu support on x86_64 (P12)
- don't break x86_64 in P8 when kqemu is enabled

* Mon Jul 25 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.7.1-1mdk
- only use gcc3.3 in 2006+ and x86
- load initrd at a higher address in pc emulation
- 0.7.1:
  * fixes to sparc64 and ppc system emulation
  * add initial support for mips system emulation
  * fixes to i386 emulation: fscale, add overflow exceptions in divisions
  * fix 64-bit virtual addressing
  * allow more than 4 GB of physical memory
  * add IO-APIC support for Windows 64
  * add support for s390 hosts
  * linux-user improvements: more set/getsockopt values, [f]truncate64,

* Thu Jul 21 2005 Pascal Terjan <pterjan@mandriva.org> 0.7.0-8mdk
- add AMD pcnet patch (faster NIC, add -nic-pcnet to use it)
- fix qvm86 description (only runs on kernels without PAE)
- enforce using gcc3.3

* Sat Jun 04 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.7.0-7mdk
- minor optimizations to x86-64 host:
  * support direct jumps
  * assembly optimizations to softmmu mode

* Thu Jun 02 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.7.0-6mdk
- fix build with gcc4 (Paul Brook)
- fix build with gcc4 on x86_64 and local dot symbols
- fix x86-64 system emulation regression introduced from qvm86 patch

* Wed Jun 01 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.7.0-5mdk
- refactor buildrequires
- add support for -sheep-net network emulation

* Tue May 17 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.7.0-4mdk
- remove double free in slirp code
- 64-bit fixes to -user-net
- cross-compilation fixes to mingw32 from 64-bit host
- selected fixes from CVS (2005/05/17):
  * Windows 2000 install disk full hack (with -win2k-hack)
  * BMDMA interrupt fix (aka Solaris x86 IDE bug fix)
  * ne2000 reset fix (aka OS/2 Warp V4 fix)
  * handle the case where several PCI irqs share the same PIC irq
  * open fix in Linux/ARM user emulation
  * ARM saturating arithmetic fixes
  * ARM VFP dump fix
  * PPC dcbz fix

* Fri May 13 2005 Pascal Terjan <pterjan@mandriva.org> 0.7.0-3mdk
- Support qvm86 instead

* Wed May 11 2005 Pascal Terjan <pterjan@mandriva.org> 0.7.0-2mdk
- Enable kqemu support

* Fri Apr 29 2005 Pascal Terjan <pterjan@mandriva.org> 0.7.0-1mdk
- 0.7.0
- regenerate P1
- add new targets

* Sun Nov 14 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.6.1-1mdk
- 0.6.1
- build sparc target
- add initial sparc host cpu support
- drop P0, P2 & P3 (merged upstream)
- regenerate P1

* Wed Sep 29 2004 Michael Scherer <misc@mandrake.org> 0.6.0-2mdk 
- fix memleak of userspace-net-stack, ( http://lists.gnu.org/archive/html/qemu-devel/2004-09/msg00244.html )

* Mon Sep 06 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.6.0-1mdk
- 0.6.0
- updates from CVS (2004/09/06):
  * fix x86 bound instruction
  * fix build on x86 with asm memory helpers
  * fix build on ppc

